@@ -1,14 +1,19 @@
 #!/usr/bin/env python
 import re
+
 from IPython.core.magic import (Magics, magics_class, cell_magic, line_magic,
                                 needs_local_scope)
-from IPython.config.configurable import Configurable
-from IPython.utils.traitlets import Bool, Int, Unicode
 try:
     from pandas.core.frame import DataFrame, Series
 except ImportError:
     DataFrame = None
     Series = None
+try:
+    from traitlets import Bool, Int, Unicode
+    from traitlets.config.configurable import Configurable
+except ImportError:
+    from IPython.config.configurable import Configurable
+    from IPython.utils.traitlets import Bool, Int, Unicode
 
 from neo4jrestclient.exceptions import StatusException
 
@@ -56,6 +61,9 @@ class CypherMagic(Magics, Configurable):
     feedback = Bool(defaults.feedback, config=True, help="""
         Print number of rows affected
     """)
+    uri = Unicode(defaults.uri, config=True, help="""
+        Default database URL if none is defined inline
+    """)
 
     def __init__(self, shell):
         Configurable.__init__(self, config=shell.config)
